Internal helper that normalizes user family input into one of the canonical labels used by the internal FE/Laplace code:
"binomial_probit"
"binomial_logit"
"poisson_log"
Users may pass either the canonical character labels above, or common
stats::family() objects:
stats::binomial(link = "probit")
stats::binomial(link = "logit")
stats::poisson(link = "log")
glmmfe_resolve_family(family)A canonical family label.
Character label or a stats::family() object.